==> org.robokind.impl.speech-0.8.5-sources.jar: org/robokind/impl/speech/viseme/VisemeBindingManagerAvroConfigWriter.java <==
/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.impl.speech.viseme;

import java.io.File;
import org.robokind.api.common.config.VersionProperty;
import org.robokind.api.common.services.ConfigurationWriter;
import org.robokind.api.speech.viseme.config.VisemeBindingManagerConfig;
import org.robokind.avrogen.speech.viseme.VisemeBindingManagerConfigRecord;
import org.robokind.bind.apache_avro.AvroUtils;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class VisemeBindingManagerAvroConfigWriter implements ConfigurationWriter<VisemeBindingManagerConfig, File> {

    @Override
    public VersionProperty getConfigurationFormat() {
        return VisemeBindingManagerAvroConfigLoader.VERSION;
    }

    @Override
    public boolean writeConfiguration(VisemeBindingManagerConfig config, File param) throws Exception {
        if(config == null || param == null){
            throw new NullPointerException();
        }
        VisemeBindingManagerConfigRecord record = 
                new PortableVisemeBindingManagerConfig(config).getRecord();
        return AvroUtils.writeToFile(
                record, VisemeBindingManagerConfigRecord.SCHEMA$, param, true);
    }

    @Override
    public Class<VisemeBindingManagerConfig> getConfigurationClass() {
        return VisemeBindingManagerConfig.class;
    }

    @Override
    public Class<File> getParameterClass() {
        return File.class;
    }
    
}

==> org.robokind.impl.speech-0.9.1-sources.jar: org/robokind/impl/speech/viseme/VisemeBindingManagerAvroConfigWriter.java <==
/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.impl.speech.viseme;

import java.io.File;
import org.robokind.api.common.config.VersionProperty;
import org.robokind.api.common.services.ConfigurationWriter;
import org.robokind.api.speech.viseme.config.VisemeBindingManagerConfig;
import org.robokind.avrogen.speech.viseme.VisemeBindingManagerConfigRecord;
import org.robokind.bind.apache_avro.AvroUtils;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class VisemeBindingManagerAvroConfigWriter implements ConfigurationWriter<VisemeBindingManagerConfig, File> {

    @Override
    public VersionProperty getConfigurationFormat() {
        return VisemeBindingManagerAvroConfigLoader.VERSION;
    }

    @Override
    public boolean writeConfiguration(VisemeBindingManagerConfig config, File param) throws Exception {
        if(config == null || param == null){
            throw new NullPointerException();
        }
        VisemeBindingManagerConfigRecord record = 
                (VisemeBindingManagerConfigRecord)config;
        return AvroUtils.writeToFile(
                record, VisemeBindingManagerConfigRecord.SCHEMA$, param, true);
    }

    @Override
    public Class<VisemeBindingManagerConfig> getConfigurationClass() {
        return VisemeBindingManagerConfig.class;
    }

    @Override
    public Class<File> getParameterClass() {
        return File.class;
    }
    
}
